@@ -9,7 +9,7 @@
 #'
 #' Note this only affects the specified connection.
 #'
-#' @return \code{TRUE} if the operator has been loaded.
+#' @return Always \code{TRUE}, invisibly.
 #'
 #' @param db A \code{\linkS4class{SQLiteConnection}} object to add the
 #' regular expression operator into the connection.
@@ -27,8 +27,7 @@ initRegExp <- function(db) {
          call. = FALSE)
   }
 
-  lib_path <- getLoadedDLLs()[["RSQLite"]][["path"]]
-  extension_load(db@ptr, lib_path, "sqlite3_regexp_init")
+  extension_load(db@ptr, get_lib_path(), "sqlite3_regexp_init")
 
   # always return TRUE after loading
   invisible(TRUE)
